.button-chart-settings {
    display:block;
    font-size:0.8em;
    font-weight:600;
    margin-top: -20px;
    align-self: flex-start;
}

.collapsible-target > .field {
    display: inline-block;
    width: 45%;
    margin-right: 2%;
}

.field[data-contentpath="settings"]>label {
    display: none;
}

.jexcel_content {
    box-shadow: none !important;
}


.jexcel_container {
    width: 100%;
    overflow: scroll;
}