{% load static %}
<script src="{% static 'wagtailcharts/js/chart-types.js' %}"></script>
<script src="{% static 'wagtailcharts/js/chart.js' %}"></script>
<script src="{% static 'wagtailcharts/js/stacked-100.js' %}"></script>
<script src="{% static 'wagtailcharts/js/chartjs-plugin-datalabels.min.js' %}"></script>
<script>Chart.register(ChartjsPluginStacked100.default);</script>
<script src="{% static 'wagtailcharts/js/wagtailcharts.js' %}"></script>
